# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import sso
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _SSO(GenericRedoxAbstractModel):
    _redox_module = sso


class SignOn(_SSO):

    EmailAddress: Union[str, None] = Field(None)
    Expiration: str = Field(...)
    FirstName: Union[str, None] = Field(None)
    IssuedAt: str = Field(...)
    LastName: Union[str, None] = Field(None)
    Locale: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    MiddleName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    NPI: Union[str, None] = Field(None)
    Order: generic.Order = Field(None)
    Patient: generic.Patient = Field(None)
    PhoneNumber: generic.PhoneNumber = Field(None)
    ProviderSpecialty: Union[str, None] = Field(None)
    Subject: str = Field(...)
    TimeZone: Union[str, None] = Field(None)
    UserId: Union[str, None] = Field(None)
    Visit: generic.Visit = Field(None)
