# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import research
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Research(GenericRedoxAbstractModel):
    _redox_module = research


class Study(_Research):

    Meta: generic.Meta = Field(...)
    Protocols: List[generic.Protocol] = Field(None)
    Study: generic.Study = Field(None)


class SubjectUpdate(_Research):

    Enrollment: generic.Enrollment = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)
    Study: generic.Study = Field(None)
