# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import medications
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Medications(GenericRedoxAbstractModel):
    _redox_module = medications


class Administration(_Medications):

    Administrations: List[generic.Administration] = Field(...)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Cancel(_Medications):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class New(_Medications):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Update(_Medications):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)
