# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class DocumentGet(EventTypeAbstractModel):

    Document: "DocumentGetDocument" = Field(...)
    Meta: "DocumentGetMeta" = Field(...)


class DocumentGetDocument(RedoxAbstractModel):

    ID: str = Field(...)


class DocumentGetMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["DocumentGetMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["DocumentGetMetaLog"] = Field(None)
    Message: "DocumentGetMetaMessage" = Field(None)
    Source: "DocumentGetMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "DocumentGetMetaTransmission" = Field(None)


class DocumentGetMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentGetMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DocumentGetMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DocumentGetMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentGetMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


DocumentGet.update_forward_refs()
DocumentGetMeta.update_forward_refs()
