# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import vaccination
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Vaccination(GenericRedoxAbstractModel):
    _redox_module = vaccination


class Administration(_Vaccination):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Vaccinations: List[generic.Vaccination] = Field(...)
    Visit: generic.Visit = Field(None)


class New(_Vaccination):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Vaccinations: List[generic.Vaccination] = Field(...)
    Visit: generic.Visit = Field(None)


class PatientQuery(_Vaccination):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)


class PatientQueryResponse(_Vaccination):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)
    PotentialMatches: List[generic.PotentialMatch] = Field(None)
