# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .availableslots import AvailableSlots
from .availableslotsresponse import AvailableSlotsResponse
from .booked import Booked
from .bookedresponse import BookedResponse
from .cancel import Cancel
from .modification import Modification
from .new import New
from .noshow import NoShow
from .pushslots import PushSlots
from .reschedule import Reschedule
