# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .administration import Administration
from .new import New
from .patientquery import PatientQuery
from .patientqueryresponse import PatientQueryResponse
